## Download from 'aparat.com' videos with python


**Installation**
```python
pip install aparatdownloader
```

**usage**

```python
from aparatdl import Main

a = Main(url='https://www.aparat.com/v/FIO6j', quality='240p')
a.download()
```
